==> wiki3_6_1.zip: wiki3_6_1/plugin/attach/Ref.pm <==
############################################################
#
# <p>źեեؤΥ󥫤ɽޤ</p>
# <pre>
# {{ref ե̾}}
# </pre>
# <p>̤Υڡźդ줿ե򻲾Ȥ뤳ȤǤޤ</p>
# <pre>
# {{ref ե̾,ڡ̾}}
# </pre>
# <p>
#   ̾ϥ󥫤Ȥƥե̾ɽޤ
#   ̾ȤǤդʸɽ뤳ȤǤޤ
# </p>
# <pre>
# {{ref ե̾,ڡ̾,̾}}
# </pre>
#
############################################################
package plugin::attach::Ref;
use strict;
use plugin::attach::AttachHandler;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self  = shift;
	my $wiki  = shift;
	my $file  = shift;
	my $page  = shift;
	my $alias = shift;
	
	if($file eq ""){
		return &Util::inline_error("ե뤬ꤵƤޤ");
	}
	if($page eq ""){
		$page = $wiki->get_CGI()->param("page");
	}
	unless($wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($alias eq ""){
		$alias = $file;
	}

	my $filename = $wiki->config('attach_dir')."/".&Util::url_encode($page).".".&Util::url_encode($file);
	if(-e $filename){
		my $buf = "<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;page=".
		          &Util::url_encode($page)."&amp;file=".&Util::url_encode($file)."\">".&Util::escapeHTML($alias)."</a>";
		
		# ɲ
		my $count = Util::load_config_hash(undef,$wiki->config('log_dir')."/".$wiki->config('download_count_file'));
		if(defined($count->{$page."::".$file})){
			$buf .= "(".$count->{$page."::".$file}.")";
		} else {
			$buf .= "(0)";
		}
		return $buf;
		
	} else {
		return &Util::inline_error("ե뤬¸ߤޤ");
	}
}

1;

==> wiki3_6_3dev3.zip: wiki3_6_3dev3/plugin/attach/Ref.pm <==
############################################################
#
# <p>źեեؤΥ󥫤ɽޤ</p>
# <pre>
# {{ref ե̾}}
# </pre>
# <p>̤Υڡźդ줿ե򻲾Ȥ뤳ȤǤޤ</p>
# <pre>
# {{ref ե̾,ڡ̾}}
# </pre>
# <p>
#   ̾ϥ󥫤Ȥƥե̾ɽޤ
#   ̾ȤǤդʸɽ뤳ȤǤޤ
# </p>
# <pre>
# {{ref ե̾,ڡ̾,̾}}
# </pre>
#
############################################################
package plugin::attach::Ref;
use strict;
use plugin::attach::AttachHandler;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self  = shift;
	my $wiki  = shift;
	my $file  = shift;
	my $page  = shift;
	my $alias = shift;
	
	if($file eq ""){
		return &Util::inline_error("ե뤬ꤵƤޤ");
	}
	if($page eq ""){
		$page = $wiki->get_CGI()->param("page");
	}
	unless($wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($alias eq ""){
		$alias = $file;
	}

	my $filename = $wiki->config('attach_dir')."/".&Util::url_encode($page).".".&Util::url_encode($file);
	if(-e $filename){
		my $buf = "<a href=\"".$wiki->create_url({ action=>"ATTACH",page=>$page,,file=>$file })."\">".&Util::escapeHTML($alias)."</a>";
		
		# ɲ
		my $count = Util::load_config_hash(undef,$wiki->config('log_dir')."/".$wiki->config('download_count_file'));
		if(defined($count->{$page."::".$file})){
			$buf .= "(".$count->{$page."::".$file}.")";
		} else {
			$buf .= "(0)";
		}
		return $buf;
		
	} else {
		return &Util::inline_error("ե뤬¸ߤޤ");
	}
}

1;
